@@ -16,8 +16,6 @@ class Space_DecomposedAngle(eagerx.SpaceConverter):
     @staticmethod
     @eagerx.register.spec("Space_DecomposedAngle", eagerx.SpaceConverter)
     def spec(spec: eagerx.specs.ConverterSpec, low: float, high: float, dtype: str = "float32"):
-        # Initialize spec with default arguments
-        spec.initialize(Space_DecomposedAngle)
         spec.config.update(low=low, high=high, dtype=dtype)
 
     def initialize(self, low: float, high: float, dtype: str = "float32"):
@@ -33,7 +31,7 @@ class Space_DecomposedAngle(eagerx.SpaceConverter):
         raise NotImplementedError()
 
     def B_to_A(self, msg):
-        return np.array([np.sin(msg.data), np.cos(msg.data)], dtype=self.dtype)
+        return np.array([np.cos(msg.data), np.sin(msg.data)], dtype=self.dtype)
 
 
 class Angle_DecomposedAngle(eagerx.Processor):
@@ -42,8 +40,6 @@ class Angle_DecomposedAngle(eagerx.Processor):
     @staticmethod
     @eagerx.register.spec("Angle_DecomposedAngle", eagerx.Processor)
     def spec(spec: eagerx.specs.ConverterSpec, convert_to: str = "theta_dtheta"):
-        # Initialize spec with default arguments
-        spec.initialize(Angle_DecomposedAngle)
         spec.config.update(convert_to=convert_to)
 
     def initialize(self, convert_to: str):
@@ -69,11 +65,30 @@ class Negate_Float32MultiArray(eagerx.Processor):
     @staticmethod
     @eagerx.register.spec("Negate_Float32MultiArray", eagerx.Processor)
     def spec(spec: eagerx.specs.ConverterSpec):
-        # Initialize spec with default arguments
-        spec.initialize(Negate_Float32MultiArray)
+        pass
 
     def initialize(self):
         pass
 
     def convert(self, msg: Float32MultiArray) -> Float32MultiArray:
         return Float32MultiArray(data=[-i for i in msg.data])
+
+
+class Voltage_MotorTorque(eagerx.Processor):
+    MSG_TYPE = Float32MultiArray
+
+    @staticmethod
+    @eagerx.register.spec("Voltage_MotorTorque", eagerx.Processor)
+    def spec(spec: eagerx.specs.ConverterSpec, K: float, R: float):
+        # Initialize spec with default arguments
+        spec.initialize(Voltage_MotorTorque)
+
+        spec.config.K = K
+        spec.config.R = R
+
+    def initialize(self, K: float, R: float):
+        self.K = K
+        self.R = R
+
+    def convert(self, msg: Float32MultiArray) -> Float32MultiArray:
+        return Float32MultiArray(data=[-msg.data[0] * self.K / self.R])
